<?php

namespace Drupal\templating\Form;


use Drupal\Component\Utility\UrlHelper;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\Core\Render\Markup;
/**
 * Edit config variable form.
 */
class ConfigTemplateEditor extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'config_template_edit_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $config_name = '') {
      $services = \Drupal::service('templating.manager');
      $query = $this->getRequest()->query ;
      $config_name = $query->get('config');
      $config = \Drupal::config($config_name) ;
      $output =  $config->get('content');
      $status =  ($config->get('status'))? $config->get('status'): false ;
      $name = $services->removePrefix($config_name);
      $status_acer =  \Drupal::moduleHandler()->moduleExists('ace_editor') ;
      if($status_acer ){
          $form['content'] = [
              '#type' => 'text_format',
              '#title' => $this->t('Edit Template  '.$name),
              '#format' => 'twig_code',
              '#default_value' => $output,
          ];
      }
      $form['config_name'] = array(
          '#type' => 'hidden',
          '#default_value' =>  $config_name
      );
      $form['status'] = array(
          '#type' => 'checkbox',
          '#title' => t('Enable template inline'),
          '#default_value' =>  $status
      );
        $form['actions'] = ['#type' => 'actions'];
        $form['actions']['submit'] = [
          '#type' => 'submit',
          '#value' => $this->t('Save Template'),
        ];
//        $form['actions']['revert'] = [
//              '#type' => 'submit',
//              '#value' => 'Import',
//              '#submit' => [[$this, 'revertProcess']],
//        ];

       $form['actions']['cancel'] = array(
          '#type' => 'link',
          '#title' => $this->t('Back to Template list'),
          '#url' => $this->buildCancelLinkUrl(),
        );

    return $form;
  }
  public function revertProcess(array &$form, FormStateInterface $form_state)
  {
      $values = $form_state->getValues();
      if(isset($values['config_name'])){
          $config_name = $values['config_name'];
          $config = \Drupal::config($config_name) ;
          $theme_name = $config->get('theme') ;
          $theme = \Drupal::service('extension.list.theme')->getPath($theme_name);
          $services = \Drupal::service('templating.manager');
          $name = $services->removePrefix($config_name);
          $element = DRUPAL_ROOT."/".$theme."/templates/templating/".$name;
          if (file_exists($element)) {
              $content = file_get_contents($element, FILE_USE_INCLUDE_PATH);
              if($content){
                  $this->configFactory()->getEditable($config_name)
                      ->set('content',$content)
                      ->set('status',$values['status'])
                      ->save();
                  $this->messenger()->addMessage($this->t('Template '.$name.' imported  was successfully'));
              }else{
                  $this->messenger()->addMessage($this->t('Template '.$name.' have content Error '),'error');
              }
          } else {
              $this->messenger()->addMessage($this->t('Template '.$name.' not  exit in theme : '. $theme_name),'error');
          }

      }
  }
  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
      $query = $this->getRequest()->query ;
      $config_name = $query->get('config');
      $values = $form_state->getValues();
      if($config_name && $values['content']){
          $content = $values['content']['value'] ;
          $this->configFactory()->getEditable($config_name)
              ->set('content',$content)
              ->set('status',$values['status'])
              ->save();
          $this->messenger()->addMessage($this->t('Config '.$config_name.' update  was successfully'));
      }

  }
  private function buildPreview() {

      $query = $this->getRequest()->query ;
      $config_name = $query->get('config');
      $config = \Drupal::config($config_name) ;
      $type =  $config->get('type');
      $entityQuery = \Drupal::entityQuery('block_content');
      $entityQuery->condition('type', $type);
      $entityQuery->range(0, 1);
      $blocks = $entityQuery->execute();

      $url = Url::fromRoute('templating.preview_page_controller_preview',
          ["entitype" => "block_content" , "id" => reset($blocks)]);
      return $url;
  }
  /**
   * Builds the cancel link url for the form.
   *
   * @return Url
   *   Cancel url
   */
  private function buildCancelLinkUrl() {
    $query = $this->getRequest()->query;

    if ($query->has('destination')) {
      $options = UrlHelper::parse($query->get('destination'));
      $url = Url::fromUri('internal:/' . $options['path'], $options);
    }
    else {
      $url = Url::fromRoute('templating.manager');
    }

    return $url;
  }

}
