<?php

namespace Drupal\templating\Form;


use Drupal\Component\Utility\UrlHelper;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;

/**
 * Edit config variable form.
 */
class ConfigTemplateSetting extends FormBase
{

    protected $step = -1;
    /**
     * {@inheritdoc}
     */
    public function getFormId()
    {
        return 'config_template_settings_form';
    }

    /**
     * {@inheritdoc}
     */
    public function buildForm(array $form, FormStateInterface $form_state, $config_name = '')
    {
        $config_settings = \Drupal::config("template_inline.settings") ;
        $services = \Drupal::service('templating.manager');
        $themes = $services->getThemeList();
        $theme_options = [];
        foreach(array_keys($themes) as $theme){
            $theme_options[$theme] = $theme ;
        }
        $form['theme'] = [
            '#type' => 'checkboxes',
            '#title' => t('Theme'),
            '#options' => $theme_options,
            '#multiple' => TRUE,
            '#required' => TRUE,
            '#default_value' =>  ($config_settings->get('theme'))? $config_settings->get('theme'): [] ,
        ];
        $form['enabled'] = array(
            '#type' => 'checkbox',
            '#title' => t('Enabled template inline'),
            '#default_value' =>  ($config_settings->get('enabled'))? $config_settings->get('enabled'): false 
        );
        $form['actions'] = ['#type' => 'actions'];
        $form['actions']['submit'] = [
            '#type' => 'submit',
            '#value' => $this->t('Save'),
        ];
        $form['actions']['cancel'] = array(
            '#type' => 'link',
            '#title' => $this->t('Back to Template list'),
            '#url' => $this->buildCancelLinkUrl(),
        );
        return $form;

    }

    /**
     * Builds the cancel link url for the form.
     *
     * @return Url
     *   Cancel url
     */
    private function buildCancelLinkUrl()
    {
        $query = $this->getRequest()->query;
        if ($query->has('destination')) {
            $options = UrlHelper::parse($query->get('destination'));
            $url = Url::fromUri('internal:/' . $options['path'], $options);
        } else {
            $url = Url::fromRoute('templating.manager');
        }

        return $url;
    }

    /**
     * {@inheritdoc}
     */
    public function validateForm(array &$form, FormStateInterface $form_state)
    {
    }

    /**
     * {@inheritdoc}
     */
    public function submitForm(array &$form, FormStateInterface $form_state)
    {
        $values = $form_state->getValues();
            // saving section

        $this->configFactory()->getEditable('template_inline.settings')
                        ->set('enabled', $values['enabled'])
                        ->set('theme', $values['theme'])
                        ->save();
    }

}
